# Tuitoy
v 0.0.2

## Table of Content
* [About](#about)
* [To do](#to-do)
* [Version history](#version-history)

## About

Terminal User Interface Toy
This is a library designed to make terminal application by drawing windows and components using python curses

## To do
[ ] - Complete a well documented README with descriptions of all the classes and functions allowing for users to create custom components by extending existing classes

## Version history
- 0.0.1 initial upload
- 0.0.2 Hot fix for scene input handling and reorganizing the project and allows for `from tuitoy import *`
